#!/bin/sh
VER=1.1
#--------------------------------------------------------------------#
# Tur-Dupelog by Turranius ( http://www.grandis.nu/glftpd/ )         #
#--------------------------------------------------------------------#
# This is the data part of the script. You need to edit this to set  #
# where it should look, and what it should exclude.                  #
#                                                                    #
#-[ Installation ]---------------------------------------------------#
# Put this script together with tur-dupelog.sh and make them both    #
# executable. Once you have it working like you want, crontab it to  #
# run as often as you like                                           #
# Set the following settings.                                        #
#                                                                    #
# SECTIONS=  What folders should I check in? I will not go deeper    #
#            then what you set here, so I wont log CD1 ets from      #
#            various releases. Separate sections with a space.       #
#                                                                    #
# DATEDDIRS= These folders contains dated dirs that you want to      #
#            include in the new dirlog.                              #
#            This will take a lot longer.                            #
#            Separate dated folders with a space                     #
#            Set it to "" if you dont want/have any.                 #
#                                                                    #
# EXCLUDE=   Any folders in these sections you want me not to log?   #
#            I guess pre folders are nice. Or anything nuked?!       #
#            If I folder contains this, it will not be logged.       #
#            Separate the folders with a space.                      #
#            These are NOT for dated dirs.                           #
#                                                                    #
# DATEDEXC=  Any folders in the dated dir structure you want me to   #
#            exclude from the new dirlog?                            #
#            Separate with a space.                                  #
#                                                                    #
# If you havent already, edit tur-dupelog.sh too.                    #
#                                                                    #
#-[ Note ] ----------------------------------------------------------#
# If you run this script as is, it will show you on screen what will #
# happen.                                                            #
#                                                                    #
#-[ Contact ]--------------------------------------------------------#
# Contact me on Efnet (Turranius / Turran / Turr|away / Turr|work)   #
#                                                                    #
#-[ Changelog ]------------------------------------------------------#
# 1.1 : Add: Support for dated folders.                              #
# 1.0 : Initial release                                              #
#                                                                    #
#-[ Settings ]-------------------------------------------------------#

SECTIONS="/glftpd/site/VCD /glftpd/site/SVCD /glftpd/site/DIVX /glftpd/site/XXX /glftpd/site/ISO-UTILS"
DATEDDIRS="/glftpd/site/0DAYS"

EXCLUDE='GROUPS _PRE NUKED'
DATEEXC='!Today !Yesterday GROUPS _PRE'

## Note, these 2 above must not be empty. Leave a dummy there if you dont want anything excluded
## like EXCLUDE='fkFDWjfklje' or something.


################################################################################
# No changes needed below here, unless your name is soehest and you run fbsd   #
################################################################################

## Change that space in excludes.
EXCLUDE="$( echo $EXCLUDE | tr -s ' ' '|' )"
if [ "$DATEEXC" != "" ]; then
  DATEEXC="$( echo $DATEEXC | tr -s ' ' '|' )"
fi

## Normal sections
for section in $SECTIONS; do

  if [ -e $section ]; then
    cd $section
  else
    echo "tur-dupelog.sh: Cant find $section. Stopping until this is fixed"
    exit 1
  fi

  for each in `ls -l --full-time | egrep -iv $EXCLUDE | cut -b 48-200 | tr -s ' ' '^'`; do
    MONTH="$( echo $each | awk -F"^" '{print $1}' )"
    DATE="$( echo $each | awk -F"^" '{print $2}' )"
    YEAR="$( echo $each | awk -F"^" '{print $4}' )"
    NAME="$( echo $each | awk -F"^" '{print $5}' )"

    YEAR="$( echo $YEAR | cut -b 3- )"

  case $MONTH in
    Jan) MONTH="01" ;;
    Feb) MONTH="02" ;;
    Mar) MONTH="03" ;;
    Apr) MONTH="04" ;;
    May) MONTH="05" ;;
    Jun) MONTH="06" ;;
    Jul) MONTH="07" ;;
    Aug) MONTH="08" ;;
    Sep) MONTH="09" ;;
    Oct) MONTH="10" ;;
    Nov) MONTH="11" ;;
    Dec) MONTH="12" ;;
    *) MONTH="01" ;;
  esac
  
  ## Spit it out!  
  echo "$YEAR$MONTH$DATE $NAME"

  done
done

##############################################
############################# Dated dirs.. zzz
##############################################

if [ "$DATEDDIRS" = "" ]; then
  exit 0
fi

for dated in $DATEDDIRS; do
  cd $dated
  for eachf in `ls -L | egrep -iv $DATEEXC`; do

    if [ -e $dated/$eachf ]; then
      cd $dated/$eachf
    else
      echo "tur-dupelog.sh: Cant find $dated/$eachf. Stopping until this is fixed"
      exit 1
    fi

    for each in `ls -l --full-time | egrep -iv $EXCLUDE | cut -b 48-200 | tr -s ' ' '^'`; do
      MONTH="$( echo $each | awk -F"^" '{print $1}' )"
      DATE="$( echo $each | awk -F"^" '{print $2}' )"
      YEAR="$( echo $each | awk -F"^" '{print $4}' )"
      NAME="$( echo $each | awk -F"^" '{print $5}' )"

      YEAR="$( echo $YEAR | cut -b 3- )"

    case $MONTH in
      Jan) MONTH="01" ;;
      Feb) MONTH="02" ;;
      Mar) MONTH="03" ;;
      Apr) MONTH="04" ;;
      May) MONTH="05" ;;
      Jun) MONTH="06" ;;
      Jul) MONTH="07" ;;
      Aug) MONTH="08" ;;
      Sep) MONTH="09" ;;
      Oct) MONTH="10" ;;  
      Nov) MONTH="11" ;;
      Dec) MONTH="12" ;;
      *) MONTH="01" ;;
    esac
  
    ## Spit it out!  
    echo "$YEAR$MONTH$DATE $NAME  $eachf"

    done
  done
done

exit 0